Attribute VB_Name = "DSS_fellespublisering"
Sub DSS_1_Rydd_manus_og_fiks_tegnsetting()
'
' Makro som fikser vanlige tegnsettingsproblemer i manus. Ment for dokumenter tilknyttet fellespubliserings-mal som skal layoutes i InDesign.
'
' Makro opprettet 18.12.2020 av Jonas M. Rogne, Departementenes sikkerhets- og serviceorganisasjon.
' Sist oppdatert 23.01.2022

Application.ScreenUpdating = False 'Ikke oppdater skjermbilde mens makro kjrer (s slipper vi epileptiske anfall).

strListSep = Application.International(wdListSeparator) 'Lagre listeseparator som variabel. Dette for  sttte andre regionsinnstillinger enn norsk. M da bruke denne variabelen i stedet for semikolon i skestrenger.

ActiveDocument.AcceptAllRevisions       'Godta alle endringer
ActiveDocument.TrackRevisions = False   'Stopp sporing ("Sport Endringer" vil ellers fre til feil ved kjring av makro)

' ======= KONTROLLERE og BOKMERKER =======
' Denne koden fjerner alle kontrollere (content controls) og bokmerker.

  Dim oRng As Range
  Dim CC   As ContentControl
  Dim LC   As Integer
  Dim LRCC As Integer
  Dim LTCC As Integer
  Dim LE   As Boolean

    'Remove all content controls
    Set oRng = ActiveDocument.Content
    LTCC = LTCC + oRng.ContentControls.Count
    For LC = oRng.ContentControls.Count To 1 Step -1
    
    Set CC = oRng.ContentControls(LC)
    If CC.LockContentControl = True Then
       CC.LockContentControl = False
    End If
    CC.Delete
    If Not LE Then
        LRCC = LRCC + 1
        End If
        LE = False
    Next

    'Fjern alle bokmerker
    Dim objBookmark As Bookmark
    For Each objBookmark In ActiveDocument.Bookmarks
      objBookmark.Delete
    Next

    'Sett tabellstilen "StandardBoks" p tabeller med 1 celle
    Dim tbl As Table
    For Each tbl In ActiveDocument.Tables
        If tbl.Range.Information(wdWithInTable) = True Then
            If tbl.Rows.Count = 1 And tbl.Columns.Count = 1 Then
                tbl.Style = "StandardBoks"
            End If
        End If
    Next tbl

' ======= HOVEDDEL =======
' Her kommer hoveddelen av makroen. Den kjrer to ganger (en gang for innhold, en gang for fotnoter).
' Delene som fikser ting unikt for fotnoter kan antagelig forbedres s koden blir ryddigere.

' Har du flere sk-og-erstatt-strenger du nsker  legge til som skal kjres p bde innhold og fotnoter,
' foreslr jeg  legge det i starten av denne For-loopen.

ActiveDocument.StoryRanges(wdMainTextStory).Select 'Marker dokumentteksten (s man ikke str i f.eks. fotnoter)

For i = 1 To 2 'Loop n gang - 2. gangen den kjrer gjennom vil vre for fotnoter

    'Bytt  som er laget som et sammensatt tegn, med vanlig .
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "a" & ChrW(778)
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Fjern "zero width space". Et usynlig tegn som av og til kommer med p tekst kopiert fra lovdata.no.
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^u8203" 'Zero width space er unicode 8203
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "[^12^14]" 'Erstatt inndelingsskift/sideskift/spalteskift
        .Replacement.Text = "^p" 'Med vanlig avsnitt (evt. doble avsnitt fjernes senere i makro)
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = " {2" & strListSep & "}" '2 eller flere mellomrom
        .Replacement.Text = " " 'reduser til ett
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^t{2" & strListSep & "}" '2 eller flere tabulatorer
        .Replacement.Text = "^t" 'reduser til en
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^t " 'Tabulator + mellomrom
        .Replacement.Text = "^t" 'reduser til kun tabulator
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = " ^t" 'Mellomrom + Tabulator
        .Replacement.Text = "^t" 'reduser til kun tabulator
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ".{3" & strListSep & "}" '3 eller flere punktum
        .Replacement.Text = "" 'endre til ellipse
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "[""" & ChrW(8220) & "]..<" '2 punktum i startet av sitat
        .Replacement.Text = """" 'endre til ellipse
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "> ..""" 'mellomrom og 2 punktum i slutten av sitat
        .Replacement.Text = " """ 'endre til ellipse
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = " .. " '2 punktum med mellomrom rundt
        .Replacement.Text = "  " 'endre til ellipse
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = ".." 'endre to punktum
        .Replacement.Text = "." 'til ett punktum
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Fjern mellomrom eller tabulator i starten av avsnitt.
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^13[ ^t]" 'Avsnitt + (mellomrom eller Tab)
        .Replacement.Text = "^p" 'Avsnitt
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    
    '==== Denne delen av koden fjerner tomme avsnitt ====
    
    Dim MyRange As Range, oTable As Table, oCell As Cell 'Setter variabler som brukes snart
        
    ' Reduser 2 eller flere tomme avsnitt til ett
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "^13{2" & strListSep & "}" '2 eller fler avsnittstegn
        .Replacement.Text = "^p" 'reduser til ett
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
        .Execute Replace:=wdReplaceAll
    End With
    
    ' Slett tomt avsnitt hvis det er frste avsnitt
    Set MyRange = ActiveDocument.Paragraphs(1).Range
    If MyRange.Text = vbCr Then MyRange.Delete
    
    ' Slett tomt avsnitt hvis det er siste avsnitt
   ' Set MyRange = ActiveDocument.Paragraphs.Last.Range
   ' If MyRange.Text = vbCr Then MyRange.Delete

    
    ' For hver tabell (skal vi g gjennom tabellcellene og fjern tomme avsnitt i start/slutt)
    For Each oTable In ActiveDocument.Tables
    
        Set oCell = oTable.Range.Cells(1)
        'For hver celle i tabellen
        For Counter = 1 To oTable.Range.Cells.Count
    
            If Len(oCell.Range.Text) > 2 And _
                    oCell.Range.Characters(1).Text = vbCr Then
                'hvis cellen ikke er tom, men starter med et tomt avsnitt, slett avsnittet
                'Merk at en tom celle inneholder to tegn; avsnittsmerket og tegn for celleslutt
                oCell.Range.Characters(1).Delete
            End If
    
            If Len(oCell.Range.Text) > 2 And _
                    Asc(Right$(oCell.Range.Text, 3)) = 13 Then
                'hvis cellen ikke er tom, men slutter med et tomt avsnitt, slett avsnittet
                Set MyRange = oCell.Range
                MyRange.MoveEnd Unit:=wdCharacter, Count:=-1
                MyRange.Characters.Last.Delete
            End If
    
            Set oCell = oCell.Next
        Next Counter
    Next oTable
    
    '==== Ferdig med  fjerne tomme avsnitt ====
    
    
    
    If i = 1 Then 'Kjr denne kun p body - ikke fotnoter (gir problemer der)
        'Fjern mellomrom eller tabulator i slutten av avsnitt.
        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        With Selection.Find
            .Text = "[ ^t]^13" '(Mellomrom eller tabulator) + avsnitt
            .Replacement.Text = "^p" 'Avsnitt
            .Forward = True
            .Wrap = wdFindContinue
            .Format = False
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = True 'obs
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
    End If
    

    With Selection.Find
        .Text = " - " 'Bytt bindestrek med luft rundt
        .Replacement.Text = " ^= " 'til tankestrek med luft rundt
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    

'==== 11 skestrenger som fikser vanlige skrivefeil i Prop./NOU/St.Meld/Innst. ====

    Options.DefaultHighlightColorIndex = wdTurquoise 'Setter en uthevings-farge s utheving/highlighting fungerer
    
    'Vi starter med  utheve sitater. Dette s vi kan utelate de nr vi retter skrivefeil.
    Selection.Find.ClearFormatting
    Selection.Find.Style = ActiveDocument.Styles("blokksit") 'Finn alle blokksitater
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Highlight = True 'Uthev bokksitatene
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'Obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll


    'Finn og fiks "Meld. St." med feil mellomrom/punktum og stor/liten forbokstav
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Kun sk p tekst som ikke er uthevet (sitater er uthevet, s de vil ikke pvirkes)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<[Mm]eld[ .]{1" & strListSep & "2}[Ss]t. ([0-9])"
        .Replacement.Text = "Meld. St. \1"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'Obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Finn og fiks "St.meld. nr. #" med feil mellomrom/punktum og feil med stor/liten forbokstav
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<[Ss]t[ .]{1" & strListSep & "2}[Mm]eld[ .]{1" & strListSep & "2}[Nn]r. ([0-9]{1" & strListSep & "3})"
        .Replacement.Text = "St.meld. nr. \1"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'Obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Finn og fiks "Ot/St.prp. nr. #" med feil mellomrom/punktum og feil med stor/liten forbokstav i prp/nr
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<([OS]t)[ .]{1" & strListSep & "2}[Pp]rp[ .]{1" & strListSep & "2}[Nn]r. ([0-9]{1" & strListSep & "3})"
        .Replacement.Text = "\1.prp. nr. \2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'Obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Finn "Prop ### L/S/LS" uten punktum, og legg til punktum. Fiks ogs manglende stor forbokstav.
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<[Pp]rop[ .]{1" & strListSep & "2}([0-9]{1" & strListSep & "3} [LS]{1" & strListSep & "2} \([0-9]{4})"
        .Replacement.Text = "Prop. \1"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Finn to firesifrede rstall i parentes (fra-til) og fjern luft (og gi de tankestrek).
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Kun sk p tekst som ikke er uthevet (sitater er uthevet, s de vil ikke pvirkes)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "(\([12][0189][0-9]{2}) [-] ([12][0189][0-9]{2}\))"
        .Replacement.Text = "\1\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Finn to firesifrede rstall i parentes (fra-til) og gi de tankestrek.
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "(\([12][0189][0-9]{2})-([12][0189][0-9]{2}\))"
        .Replacement.Text = "\1\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Finn NOU og legg til manglende mellomrom etter kolon og fiks feil med store/sm forbokstaver
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<[Nn][Oo][Uu]( [12][09][0-9]{2}:)([0-9]{1" & strListSep & "3})"
        .Replacement.Text = "NOU\1 \2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Fjern luft i rstall for St.Meld. (etter korrigert av skrivemte for St.Meld. tidligere i makro)
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<(St.meld. nr. [0-9]{1" & strListSep & "3} \([0-9]{4}) [-] ([0-9]{2" & strListSep & "4}\))"
        .Replacement.Text = "\1^=\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Fjern luft i rstall for Ot/St.prp. (etter korrigert skrivemte)
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "([OS]t.prp. nr. [0-9]{1" & strListSep & "3} \([0-9]{4}) [-] ([0-9]{2" & strListSep & "4}\))"
        .Replacement.Text = "\1^=\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Bytt til tankestrek i rstall for St.Meld. (etter korrigert av skrivemte for St.Meld.)
    With Selection.Find
        .Text = "<(St.meld. nr. [0-9]{1" & strListSep & "3} \([0-9]{4})\-([0-9]{2" & strListSep & "4}\))"
        .Replacement.Text = "\1^=\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Bytt til tankestrek i rstall for St.prp. og Ot.prp. (etter korrigert skrivemte for S/Ot.prp.)
    With Selection.Find
        .Text = "([OS]t.prp. nr. [0-9]{1" & strListSep & "3} \([0-9]{4})\-([0-9]{2" & strListSep & "4}\))"
        .Replacement.Text = "\1^=\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    
    'Korriger skrivemte for Innst. (L, S, LS, SL)
    Selection.Find.ClearFormatting
    Selection.Find.Highlight = False 'Ekskluder uthevet tekst (sitater)
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "<[Ii]nnst[ .]{1" & strListSep & "2}([0-9]{1" & strListSep & "3} [LS]{1" & strListSep & "2} \([0-9]{4})([0-9]{4}\))"
        .Replacement.Text = "Innst. \1^=\2"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True 'obs
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    'Fjern den midlertidige uthevingen fra sitatene igjen
    Selection.Find.ClearFormatting
    Selection.Find.Style = ActiveDocument.Styles("blokksit") 'For sitater
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Highlight = False 'Fjern utheving
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    
'==== Ferdig med  fikse skrivefeil i RDOK-navn ====

       
       
'------------------- Denne delen fikser anfrselstegn -------------------------
' Denne makroen benytter Word's innebyggde funksjon for "Smart Quotes"/"typografiske anfrselstegn" til  oppdatere anfrselstegn og apostrofer.

    ' Sl p innstillingen for "Smart Quotes"-autokorrektur
    Options.AutoFormatAsYouTypeReplaceQuotes = True

    ' Oppdater alle doble anfrselstegn:
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = """"             'Sk etter "
        .Replacement.Text = """" 'Erstatt med "
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    ' Oppdater alle enkle anfrselstegn/apostrofer:
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "'"             'Sk etter '
        .Replacement.Text = "'" 'Erstatt med '
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    ' Bytt fra doble engelske til doble norske anfrselstegn. (I tilfelle forrige erstatning ble feil pga. sprk, eller hvis engelske var lagt inn fra fr).
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    ' Endre okina til  (det har forekommet at noen har brukt okina i stedet for vanlig enkelt anfrselstegn)!
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ChrW(699)
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    ' Endre "Modifier letter apostrophe" til  (det har forekommet at noen har brukt dette i stedet for vanlig enkelt anfrselstegn)
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ChrW(700)
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    

'-------------------^ Anfrselstegn er n fikset ^-------------------------
    
    
    'Harde ordmellomrom fjernes. (Etterflgende sk-og-erstatt-strenger setter inn nye).
    With Selection.Find
        .Text = "^s"
        .Replacement.Text = " "
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = " ([0-9])" 'Paragraftegn og mellomrom som etterflges av tall
        .Replacement.Text = "^s\1" 'Endre til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = "([0-9]) ([0-9]{3})" 'Et tall ettefulgt av mellomrom og s tre tall
        .Replacement.Text = "\1^s\2" 'Bruk hardt mellomrom mellom tallene (tusenskille)
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    Selection.Find.Execute Replace:=wdReplaceAll
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    With Selection.Find.Font
        .Superscript = True 'Obs!
        .Subscript = False
    End With
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles("skrift-hevet")
    With Selection.Find
        .Text = "[!^2]"             'Finn hevet tekst *som ikke er en fotnotereferanse*
        .Replacement.Text = "^&"    'Behold teksten; men stilen settes til "skrift-hevet"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchKashida = False
        .MatchDiacritics = False
        .MatchAlefHamza = False
        .MatchControl = False
        .MatchWildcards = True      'Obs!
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    With Selection.Find.Font
        .Superscript = False
        .Subscript = True 'Obs!
    End With
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles("skrift-senket")
    With Selection.Find
        .Text = ""                  'Finn senket tekst*
        .Replacement.Text = "^&"    'Behold teksten; men stilen settes til "skrift-senket"
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchKashida = False
        .MatchDiacritics = False
        .MatchAlefHamza = False
        .MatchControl = False
        .MatchWildcards = True      'Obs!
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = "([0-9]) mill." 'Tall etterfulgt av mill.
        .Replacement.Text = "\1^smill." 'Bytt til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = "([0-9]) mrd." 'Tall etterfulgt av mrd.
        .Replacement.Text = "\1^smrd." 'Bytt til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = "([0-9]) kroner" 'Tall etterfulgt av kroner
        .Replacement.Text = "\1^skroner" 'Bytt til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = "([0-9]) pst." 'Tall etterfulgt av pst.
        .Replacement.Text = "\1^spst." 'Bytt til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    With Selection.Find
        .Text = "([0-9]) %([0-9]) %" 'Tall etterfulgt av %
        .Replacement.Text = "\1^s%" 'Bytt til hardt mellomrom
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = True 'obs
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
   
   
   '---Skestrenger for  fikse mange forekomster av feil bruk av kursiv og fet---
   '---Fikser ikke gjennomstrek/understrek/sperret---
   '---Forutsetter at fotnoter har stilen "Fotnotetekst"---
   '---Fjerner ikke halvfet/kursiv tegnstil fra titler som i utgangspunktet er halvfet/kursiv---
   
   '---Fiks de fleste forekomster av italic/bold:---
   
    Selection.Find.ClearFormatting
    Selection.Find.Style = ActiveDocument.Styles("kursiv") 'Hvis avsnittet har tegnstilen Kursiv
    With Selection.Find.Font
        .Italic = False                                    'Men ikke vises som kursiv
    End With
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles( _
        "Standardskrift for avsnitt")                      'Fjern tegnstilen (kursiv)
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Style = ActiveDocument.Styles("halvfet") 'Hvis avsnittet har tegnstilen halvfet
    With Selection.Find.Font
        .Bold = False                                       'Men ikke vises som bold
    End With
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles( _
        "Standardskrift for avsnitt")                       'Fjern tegnstilen (halvfet)
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
   
        Dim KursivAllowed As String
        Dim RngFind As Range, RngTxt As Range, stilnr As Long
        'Alfabetisk liste med stiler som tillater kursiv tegnstil (ca. alt utenom titler):
        KursivAllowed = "alfaliste,alfaliste 2,alfaliste 3,alfaliste 4,alfaliste 5,blokksit,friliste,friliste 2,friliste 3,friliste 4,friliste 5,hengende-innrykk,Kilde,Liste,Liste 2,Liste 3,Liste 4,Liste 5,Liste bombe,Liste bombe 2,Liste bombe 3,Liste bombe 4,Liste bombe 5,Listeavsnitt,Listeavsnitt 2,Listeavsnitt 3,Listeavsnitt 4,Listeavsnitt 5,Normal,Note,Nummerert liste,Nummerert liste 2,Nummerert liste 3,Nummerert liste 4,Nummerert liste 5,Opplisting,Opplisting 2,Opplisting 3,Opplisting 4,Opplisting 5,Petit,romertall liste,romertall liste 2,romertall liste 3,romertall liste 4,romertall liste 5,TabellHode-kolonne,TabellHode-rad"
                Set RngTxt = Selection.Range
        For stilnr = 0 To UBound(Split(KursivAllowed, ","))      'Loop gjennom stiler som tillater kursiv
          Set RngFind = RngTxt.Duplicate
          With RngFind.Find
            .ClearFormatting
            .Style = ActiveDocument.Styles(Split(KursivAllowed, ",")(stilnr)) 'Finn tekst med den aktuelle stilen
            .Replacement.ClearFormatting
            .Replacement.Style = ActiveDocument.Styles("kursiv") 'Skal f tegnstilen kursiv
            .Font.Italic = True                                  'Hvis teksten er kursiv
            .Text = ""
            .Replacement.Text = ""
            .Forward = True
            .Wrap = wdFindContinue
            .Format = True
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
            .Execute Replace:=wdReplaceAll
          End With
        Next
        
        Dim BoldAllowed As String
        'Dim RngFind As Range, RngTxt As Range, stilnr As Long
        'Alfabetisk liste med stiler som tillater halvfet tegnstil (ca. alt utenom titler):
        BoldAllowed = "alfaliste,alfaliste 2,alfaliste 3,alfaliste 4,alfaliste 5,blokksit,friliste,friliste 2,friliste 3,friliste 4,friliste 5,hengende-innrykk,Kilde,Liste,Liste 2,Liste 3,Liste 4,Liste 5,Liste bombe,Liste bombe 2,Liste bombe 3,Liste bombe 4,Liste bombe 5,Listeavsnitt,Listeavsnitt 2,Listeavsnitt 3,Listeavsnitt 4,Listeavsnitt 5,Normal,Note,Nummerert liste,Nummerert liste 2,Nummerert liste 3,Nummerert liste 4,Nummerert liste 5,Opplisting,Opplisting 2,Opplisting 3,Opplisting 4,Opplisting 5,Petit,romertall liste,romertall liste 2,romertall liste 3,romertall liste 4,romertall liste 5,TabellHode-kolonne,TabellHode-rad"
                Set RngTxt = Selection.Range
        For stilnr = 0 To UBound(Split(BoldAllowed, ","))       'Loop gjennom stiler som tillater halvfet
          Set RngFind = RngTxt.Duplicate
          With RngFind.Find
            .ClearFormatting
            .Style = ActiveDocument.Styles(Split(BoldAllowed, ",")(stilnr)) 'Finn tekst med den aktuelle stilen
            .Replacement.ClearFormatting
            .Replacement.Style = ActiveDocument.Styles("halvfet") 'Skal f tegnstilen halvfet
            .Font.Bold = True                                     'Hvis teksten er bold
            .Text = ""
            .Replacement.Text = ""
            .Forward = True
            .Wrap = wdFindContinue
            .Format = True
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
            .Execute Replace:=wdReplaceAll
          End With
        Next
    
    Selection.Find.ClearFormatting
    Selection.Find.Style = ActiveDocument.Styles("Fotnotetekst") 'Hvis avsnittet har stilen Fotnotetekst
    Selection.Find.Font.Bold = True                              'Og er bold
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles("halvfet") 'Sett p tegnstilen "halvfet"
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Style = ActiveDocument.Styles("Fotnotetekst") 'Hvis avsnittet har stilen Fotnotetekst
    Selection.Find.Font.Italic = True                            'Og er kursiv
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles("kursiv") 'Sett p tegnstilen "kursiv"
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    Selection.Find.Replacement.Style = ActiveDocument.Styles( _
        "Fotnotereferanse")         'Legg stilen "Fotnotereferanse"
    With Selection.Find
        .Text = "^f"                'P alle fotnotereferanser (dette gjres fordi de kan ha blitt kursiv etter forrige skestrenger)
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    
    
    '---ferdig med  fikse kursiv---
       
       
    
    If ActiveDocument.Footnotes.Count <> 0 Then 'Hvis dokumentet har fotnoter:
      
      'Denne biten kode fjerner mellomrommet i starten av fotnotetekst. Code by Paul Edstein.
      Dim FtNt As Footnote
      For Each FtNt In ActiveDocument.Footnotes
        With FtNt.Range.Characters.First.Previous
          If .Text = " " Then .Text = vbNullString 'Bytt vbNullString til vbTab hvis du vil legge til tab i stedet
        End With
      Next
            
      'Marker fotnotene (s nr den straks looper blir de prosessert i stedet for innhold).
      ActiveDocument.Footnotes(1).Range.WholeStory
      ActiveDocument.Footnotes(1).Range.Select
      
      'Fjern parentes etter fotnotereferansene (kun i fotnoter, ikke i body)
      Selection.Find.ClearFormatting
      Selection.Find.Replacement.ClearFormatting
      With Selection.Find
        .Text = "(^2)\)"         'Fotnotereferanse+parentes
        .Replacement.Text = "\1" 'behold kun fotnotereferanse
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchAllWordForms = False
        .MatchSoundsLike = False
        .MatchWildcards = True
      End With
      Selection.Find.Execute Replace:=wdReplaceAll
      
' DISSE LINJENE ER KOMMENTERT UT DA DEN KAN SKAPE EN UENDELIG LOOP HVIS DET EKSISTERER EN TOM FOTNOTE (men fungerer ellers bra). Noen som vet hvordan det kan gjres bedre?
'       'Fjern ekstra avsnitt i fotnotene
'        NoteCount = ActiveDocument.Footnotes.Count
'
'        Selection.Find.ClearFormatting
'        Selection.Find.Replacement.ClearFormatting
'        With Selection.Find
'            .Text = "^p^p"
'            .Replacement.Text = ""
'            .Forward = True
'            .Wrap = wdFindContinue
'            .Format = False
'            .MatchCase = False
'            .MatchWholeWord = False
'            .MatchAllWordForms = False
'            .MatchSoundsLike = False
'            .MatchWildcards = False
'        End With
'        Selection.Find.Execute
'
'        On Error GoTo TrapTheError
'        While Selection.Find.Found
'
'        Selection.MoveLeft
'        'The following line may trigger an error!
'        Selection.Delete
'        Selection.Find.Execute
'
'        Wend
'        GoTo TheEnd
'
'TrapTheError:
'            ErrorCount = ErrorCount + 1
'            Selection.MoveRight
'            Selection.Delete
'            If ErrorCount < NoteCount Then Resume Next
'
'TheEnd:
    
    Else 'Hvis det ikke var fotnoter...
        i = 3 'Endre "i" s den ikke looper, da vi er ferdige.
    End If

Next 'Macro looper (n gang) hvis det er fotnoter.
   
'Tilbakestiller sk/erstatt-innstillingene (modifiser gjerne til det du normalt sker etter manuelt rett etter  ha kjrt makro).
Selection.Find.ClearFormatting
Selection.Find.Replacement.ClearFormatting
With Selection.Find
    .Text = ""
    .Replacement.Text = ""
    .Wrap = wdFindContinue
    .Format = True
    .MatchCase = False
    .MatchWholeWord = False
    .MatchKashida = False
    .MatchDiacritics = False
    .MatchAlefHamza = False
    .MatchControl = False
    .MatchWildcards = False
    .MatchSoundsLike = False
    .MatchAllWordForms = False
End With

Application.ScreenUpdating = True 'N kan skjermbilde oppdateres igjen.
   
End Sub



Sub DSS_2_Opprydding_DOCX_fra_InDesign()

'
' Denne makroen fjerner all lokal formattering i innholdstekst og fotnoter. Se over autonummerering manuelt!
'
' Makro opprettet 18.12.2020 av Jonas M. Rogne, Departementenes sikkerhets- og serviceorganisasjon.
' Denne versjonen ble sist oppdatert 09.12.2022
'
Application.ScreenUpdating = False 'Ikke oppdater skjermbilde mens makro kjrer.

If (ActiveDocument.CompatibilityMode = 11) Then  'CompatiblityMode er "11" p rtf-filer fra FM/ID, og 15 p dokumenter uten komaptibilitetsmodus.
    ActiveDocument.Convert                       'Fjern kompatibilitetsmodus. Gjr det bl.a. enklere  bytte Alt-tekst p bilder.
End If

    'Marker dokumentet, og fjern all direkte formattering (overrides)
    ActiveDocument.StoryRanges(wdMainTextStory).Select 'Make sure document text is selected (and not footnotes, footer, etc.)
    Selection.ClearCharacterDirectFormatting
    Selection.ClearParagraphDirectFormatting
    
    If ActiveDocument.Footnotes.Count <> 0 Then 'Hvis dokumentet har fotnoter:
        
    Dim FtNt As Footnote
    For Each FtNt In ActiveDocument.Footnotes   'For hver fotnote
      FtNt.Range.Select                         'Marker fotnoten
      Selection.ClearCharacterDirectFormatting  'Fjern lokal tegnformattering
      Selection.ClearParagraphDirectFormatting  'Fjern lokal avsnittsformattering
    Next
      
    End If
    
    ActiveDocument.StoryRanges(wdMainTextStory).Select 'Marker dokumentteksten (s man ikke str i f.eks. fotnoter)
    
    'Sett tabellstilen "StandardBoks" p tabeller med 1 celle
    Dim tbl As Table
    For Each tbl In ActiveDocument.Tables
        If tbl.Range.Information(wdWithInTable) = True Then
            If tbl.Rows.Count = 1 And tbl.Columns.Count = 1 Then
                tbl.Style = "StandardBoks"
            End If
        End If
    Next tbl
    
    ' Sett stilen "Normal" p alle avsnitt som kun inneholder et bilde
    Dim p As Paragraph
    Dim bFound As Boolean
    
    ' Loop through each paragraph in the document
    For Each p In ActiveDocument.Paragraphs
    
        ' Check if the paragraph only contains an image
        If p.Range.InlineShapes.Count = 1 And Len(p.Range.Text) = 2 Then
    
            ' Set the paragraph style to "Normal"
            p.Style = "Normal"
            bFound = True
    
        End If
    Next
    
    For i = 1 To 2 'Loop n gang - 2. gangen den kjrer gjennom vil vre for fotnoter

        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        With Selection.Find
            .Text = "^u173" 'Myke bindestreker fra InDesign (blir synlige i Word)
            .Replacement.Text = "" 'Slettes
            .Forward = True
            .Wrap = wdFindContinue
            .Format = False
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        With Selection.Find
            .Text = "^u0031" 'Myke bindestreker fra InDesign
            .Replacement.Text = "" 'Slettes
            .Forward = True
            .Wrap = wdFindContinue
            .Format = False
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        With Selection.Find
            .Text = "^t" 'Tabulator
            .Replacement.Text = " " 'Endre til mellomrom
            .Forward = True
            .Wrap = wdFindContinue
            .Format = False
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        With Selection.Find
            .Text = " {2" & strListSep & "}" '2 eller flere mellomrom
            .Replacement.Text = " " 'reduser til ett
            .Forward = True
            .Wrap = wdFindContinue
            .Format = False
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = True 'obs
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        
        Selection.Find.ClearFormatting
        Selection.Find.Replacement.ClearFormatting
        Selection.Find.Replacement.Style = ActiveDocument.Styles( _
            "Fotnotereferanse")         'Legg stilen "Fotnotereferanse"
        With Selection.Find
            .Text = "^f"                'P alle fotnotereferanser
            .Replacement.Text = ""
            .Forward = True
            .Wrap = wdFindContinue
            .Format = True
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
        End With
        Selection.Find.Execute Replace:=wdReplaceAll
        
        If ActiveDocument.Footnotes.Count <> 0 Then 'Hvis dokumentet har fotnoter:
            'Marker fotnotene (s nr den straks looper blir de prosessert i stedet for innhold).
            ActiveDocument.Footnotes(1).Range.WholeStory
            ActiveDocument.Footnotes(1).Range.Select
        Else 'Hvis det ikke var fotnoter...
            i = 3 'Endre "i" s den ikke looper, da vi er ferdige.
        End If
        
    Next 'Macro looper (n gang) hvis det er fotnoter.
   
    'Tilbakestiller sk/erstatt-innstillingene (modifiser gjerne til det du normalt sker etter manuelt rett etter  ha kjrt makro).
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Wrap = wdFindContinue
        .Format = True
        .MatchCase = False
        .MatchWholeWord = False
        .MatchKashida = False
        .MatchDiacritics = False
        .MatchAlefHamza = False
        .MatchControl = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With

    Application.ScreenUpdating = True 'N kan skjermbilde oppdateres igjen.

End Sub
Sub DSS_Bytt_fra_norske_til_engelske_anfrselstegn()

'
' Makroen bytter norske  med engelske  i hele dokumentet.
' Kjr denne etter oppryddings-makro fr FrameMaker hvis du har engelsk manus.
'

Application.ScreenUpdating = False 'Ikke oppdater skjermbilde mens makro kjrer.

    ' Lagre dokumentets nvrende "Smart Quotes"-autokorrektur-innstilling
    Dim SETTING As Boolean: SETTING = Options.AutoFormatAsYouTypeReplaceQuotes

    ' Sl av innstillingen for "Smart Quotes"-autokorrektur (for sikkerhets skyld)
    Options.AutoFormatAsYouTypeReplaceQuotes = False

    ' Bytt fra doble norske til doble engelske anfrselstegn
    Selection.Find.ClearFormatting
    Selection.Find.Replacement.ClearFormatting
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll
    With Selection.Find
        .Text = ""
        .Replacement.Text = ""
        .Forward = True
        .Wrap = wdFindContinue
        .Format = False
        .MatchCase = False
        .MatchWholeWord = False
        .MatchWildcards = False
        .MatchSoundsLike = False
        .MatchAllWordForms = False
    End With
    Selection.Find.Execute Replace:=wdReplaceAll

    'Tilbakestill dokumentets originale innstilling
    Options.AutoFormatAsYouTypeReplaceQuotes = SETTING

Application.ScreenUpdating = True 'N kan skjermbilde oppdateres igjen.

End Sub


